#
# spec file for package capstone
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _lto_cflags %{?_lto_cflags} -ffat-lto-objects

%define sover   5
Name:           capstone
Version:        5.0.6
Release:        1.1
Summary:        A multi-platform, multi-architecture disassembly framework
License:        BSD-3-Clause
Group:          Development/Tools/Building
URL:            https://www.capstone-engine.org
Source:         https://github.com/capstone-engine/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
BuildRequires:  pkgconfig(python3)

%description
Capstone is a disassembly framework.
disasm engine for binary analysis and reversing in the security community.

%package -n libcapstone%{sover}
Summary:        A multi-platform, multi-architecture disassembly framework
Group:          System/Libraries

%description -n libcapstone%{sover}
Capstone is a disassembly framework.

%package -n libcapstone-devel
Summary:        Development files to build upon libcapstone
Group:          Development/Libraries/C and C++
Requires:       libcapstone%{sover} = %{version}

%description -n libcapstone-devel
Development files to build upon libcapstone, C language only.

%package -n libcapstone-devel-static
Summary:        Static library for capstone
Group:          Development/Libraries/C and C++
Requires:       libcapstone-devel = %{version}

%description -n libcapstone-devel-static
Statically linked libcapstone.

%package doc
Summary:        Documentation for capstone, a disassembly framework
Group:          Documentation/Other
BuildArch:      noarch

%description doc
Capstone is a multi-architecture disassembly framework.

%package -n python3-capstone
Summary:        Python bindings for the Capstone disassembly framework
Group:          Development/Languages/Python
BuildArch:      noarch

%description -n python3-capstone
Capstone is a multi-architecture disassembly framework.

This package contains the Capstone bindings for Python.

%prep
%autosetup

%build
%define __builder ninja
%cmake \
    -DBUILD_SHARED_LIBS=ON \
    -DBUILD_STATIC_LIBS=ON \
    -DCAPSTONE_BUILD_CSTEST=OFF \
    -DCAPSTONE_BUILD_TESTS=OFF
%cmake_build

cd .. # back to the main source directory

pushd bindings/python/ || exit 1
%python3_build
popd || exit 1

%install
%cmake_install

install -m 755 -d %{buildroot}%{_docdir}/%{name}-doc/docs
install -m 644 -t %{buildroot}%{_docdir}/%{name}-doc/docs docs/README docs/*.pdf

# Available bindings: Java, OCaml, Python2 and Python3 (pure/C)
# Python3 bindings only for now
pushd bindings/python/
%python3_install
rm -rf %{buildroot}%{python3_sitelib}/%{name}/include
rm -rf %{buildroot}%{python3_sitelib}/%{name}/lib
popd

# fix pkgconfig file
sed -e '/^archive/d' -e 's|^libdir=.*|libdir=%{_libdir}|' \
    -i %{buildroot}%{_libdir}/pkgconfig/%{name}.pc

%fdupes %{buildroot}

%ldconfig_scriptlets -n libcapstone%{sover}

%files
%license LICENSE*.TXT
%{_bindir}/cstool

%files -n libcapstone%{sover}
%{_libdir}/lib%{name}.so.%{sover}*

%files -n libcapstone-devel
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/capstone/

%files -n libcapstone-devel-static
%{_libdir}/lib%{name}.a

%files -n python3-capstone
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}*.egg-info

%files doc
%license LICENSE*.TXT
%doc ChangeLog README.md
%{_docdir}/%{name}-doc/docs/

%changelog
* Sun May 11 2025 Eyad Issa <eyadlorenzo@gmail.com>
- Use %%ldconfig_scriptlets
- Update to version 5.0.6:
  * Add little endian support for TMS320c64x
  * Full changelog at
    https://github.com/capstone-engine/capstone/compare/5.0.5...5.0.6
* Sat Mar 29 2025 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 5.0.5:
  * Full changelog at
    https://github.com/capstone-engine/capstone/compare/4.0.2...5.0.5
- Use CMake for building
  * Include .cmake devel files
* Fri Apr  5 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Build with distro %%{optflags}
* Tue Jan  3 2023 Martin Wilck <mwilck@suse.com>
- Enable static library, and add libcapstone-devel-static subpackage
  (this is helpful for qemu-linux-user)
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 4.0.2
  Windows kernel-mode driver support
  - Add armv8, ppc32 & thumbv8 modes
  - Print instruction ID
  - Support CS_OPT_UNSIGNED for ATT syntax
  - Fix operand size for some instructions
  - Fix LOCK prefixes
  - Recognize xacquire/xrelease prefix
  - Fix call/jmp access mode of mem operand
  - Add ENDBR32, ENDBR64 to reduce mode
  - Other minor fixes
  - Support CS_OPT_UNSIGNED
  - Fix register access flags for memory instructions
  - Fix UMOV vess
  - Update writeback for STR_POST_REG
  - Store correct register value in op.reg_pair
  - BDZLA is absolute branch
  - Fix truncated 64bit imm operand
  - Fix base/index printing
  - Fix skipdata struct being destroyed
  - Add __repr__ for capstone.CsInsn
  - Fix Java bindings to use pointers instead of longs
  - Fix x86_op record
* Mon May 25 2020 Jan Engelhardt <jengelh@inai.de>
- Rename -docs subpackage to -doc to follow openSUSE practices.
- Descriptions: say what the package is, not what it wants to be.
* Thu Apr  9 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.0.1
  [ Core ]
  * Fix some issues for packaging (Debian, Gentoo).
  * Better support for building with Mingw.
  * cstool has new option -s to turn on skipdata mode.
  * cstool -v now report build settings of the core.
  * Add suite/capstone_get_setup.c so users can integrate with
    their own code
  * to retrieve Capstone settings at build time.
  [ Arm ]
  * Fix 4.0 regression: the tbh [r0, r1, lsl #1] instruction
    sets the operand.shift.value back again.
  * Remove ARM_REG_PC group for BX instruction.
  [ X86 ]
  * Fix: endbr32 and endbr64 instructions are now properly
    decoded in both CS_MODE_32 and CS_MODE_64.
  [ M680X ]
  * Fix some issues reported by clang-analyzer.
  [ Python ]
  * Fix skipdata setup.
  * Add getter/setter for skipdata_mnem, skipdata_callback.
  version 4.0:
  [ Core ]
  * New APIs: cs_regs_access()
  * Add new options for cs_option(): CS_OPT_MNEMONIC &
    CS_OPT_UNSIGNED & CS_OPT_SYNTAX_MASM.
  * Various updates & bugfixes for all architectures.
  * Add 4 new architectures: EVM, M68K, M680X & TMS320C64x.
  * Add new group types: CS_GRP_PRIVILEGE &
    CS_GRP_BRANCH_RELATIVE.
  * Add new error types: CS_ERR_X86_MASM.
  [ X86 ]
  * Add XOP code condition type in x86_xop_cc.
  * Add some info on encoding to cs_x86 in cs_x86_encoding.
  * Add register flags update in cs_x86.{eflags, fpu_flags}
  * Change cs_x86.disp type from int32_t to int64_t.
  * Add new groups: X86_GRP_VM & X86_GRP_FPU.
  * Lots of new instructions (AVX)
  [ ARM64 ]
  * Add instruction ARM64_INS_NEGS & ARM64_INS_NGCS.
  [ Mips ]
  * Add mode CS_MODE_MIPS2.
  [ PPC ]
  * Change cs_ppc_op.imm type from int32_t to int64_t.
  * Add new groups: PPC_GRP_ICBT, PPC_GRP_P8ALTIVEC,
    PPC_GRP_P8VECTOR & PPC_GRP_QPX.
  * Lots of new instructions (QPX among them)
  [ Sparc ]
  * Change cs_sparc_op.imm type from int32_t to int64_t.
  [ Binding ]
  * New bindings: PowerShell & VB6
- Bumped sover to 4
- Spec cleanup
* Wed Aug 15 2018 brogers@suse.com
- Update to 3.0.5
  * build static library (but still don't install), since build
  explicitly links cstool against it
* Sun Apr 15 2018 afaerber@suse.de
- Update to 3.0.5-rc2
  * Package cstool
- Adopt %%license
* Mon Feb 12 2018 stefan.bruens@rwth-aachen.de
- Correct the license tag, Capstone is BSD-3-Clause
- Provide python3 bindings
- Rename bindings subpackage to docs, it does not contain any
  bindings but documentation
- Package some more documentation
- Build with %%{optflags}
* Thu Dec 28 2017 mardnh@gmx.de
- Specfile cleanup
* Thu Apr 16 2015 duwe@suse.com
- initial version
